import os
from pathlib import Path

import click
from ishutils.common.download import download
from ishutils.common.run import run
from slugify import slugify

from .typing import AVATAR_URL


@click.command(name="avatar")
@click.option(
    "-o",
    "--output",
    type=click.Path(file_okay=False, dir_okay=True),
    default="avatar",
)
def main(output: str | Path) -> None:
    output = Path(output)
    os.makedirs(name=output / "jpg", exist_ok=True)
    os.makedirs(name=output / "png", exist_ok=True)
    for name, url in AVATAR_URL.items():
        name = slugify(name)
        jpg: Path = output / "jpg" / f"{name}.jpg"
        png: Path = output / "png" / f"{name}.png"
        download(url=url, output=jpg)
        run(args=["magick", "convert", jpg, png])



from pathlib import Path

import click

from .gpg import main as cmd_gpg
from .ssh import main as cmd_ssh


@click.group(name="export", invoke_without_command=True)
@click.pass_context
@click.option(
    "-p", "--prefix", type=click.Path(file_okay=False, dir_okay=True), default="key"
)
def main(ctx: click.Context, prefix: str | Path) -> None:
    if not ctx.invoked_subcommand:
        prefix = Path(prefix)
        cmd_gpg.main(args=["--prefix", str(prefix / "gpg")], standalone_mode=False)
        cmd_ssh.main(args=["--prefix", str(prefix / "ssh")], standalone_mode=False)
    pass


main.add_command(cmd=cmd_gpg)
main.add_command(cmd=cmd_ssh)



from typing import Optional

from ishutils.common.run import run


def gh_secret_delete(name: str, repo: Optional[str]) -> None:
    args: list[str] = ["gh", "secret", "delete", name]
    if repo:
        args += ["--repo", repo]
    run(args=args)


def gh_secret_set(name: str, body: str, repo: Optional[str]) -> None:
    args: list[str] = ["gh", "secret", "set", name, "--body", body]
    if repo:
        args += ["--repo", repo]
    run(args=args)



from pathlib import Path

import click
from ishutils.common.copy import copy

from ..typing import SSH_TYPES


@click.command(name="ssh")
@click.option(
    "-p", "--prefix", type=click.Path(file_okay=False, dir_okay=True), default="ssh"
)
def main(prefix: str | Path) -> None:
    prefix = Path(prefix)
    config_path: Path = Path.home() / ".ssh" / "config"
    if config_path.exists():
        copy(src=config_path, dst=prefix / "config")
    for ssh_type in SSH_TYPES:
        private_key_name: str = f"id_{ssh_type}"
        private_key_path: Path = Path.home() / ".ssh" / private_key_name
        if private_key_path.exists():
            copy(src=private_key_path, dst=prefix / private_key_name)
        public_key_name: str = f"id_{ssh_type}.pub"
        public_key_path: Path = Path.home() / ".ssh" / public_key_name
        if public_key_path.exists():
            copy(src=public_key_path, dst=prefix / public_key_name)



import logging

import click
from ishutils.config import config
from ishutils.logging import install

from . import __version__
from .assets.main import main as cmd_assets
from .git.main import main as cmd_git
from .key.main import main as cmd_key
from .update.main import main as cmd_update


@click.group(name="ihelper", context_settings={"show_default": True})
@click.option(
    "--log-level",
    type=click.Choice(choices=list(logging.getLevelNamesMapping().keys())),
    default=logging.getLevelName(logging.INFO),
)
@click.option("-y", "--yes", is_flag=True)
@click.version_option(version=__version__)
def main(log_level: str, yes: bool) -> None:
    install(level=logging.getLevelName(log_level))
    config.yes = yes


main.add_command(cmd=cmd_assets)
main.add_command(cmd=cmd_git)
main.add_command(cmd=cmd_key)
main.add_command(cmd=cmd_update)


if __name__ == "__main__":
    main()



import os
import string
from pathlib import Path

import click
from ishutils.common.download import download
from ishutils.common.run import run

from .typing import FONT_AWESOME_URL


@click.command(name="favicon")
@click.option("-c", "--color", default="cyan")
@click.option(
    "-o",
    "--output",
    type=click.Path(file_okay=False, dir_okay=True),
    default="favicon",
)
def main(color: str, output: str | Path) -> None:
    output = Path(output)
    for format in ["svg", "png", "ico"]:
        os.makedirs(name=output / format, exist_ok=True)
    for letter in string.ascii_lowercase:
        svg: Path = output / "svg" / f"{letter}.svg"
        png: Path = output / "png" / f"{letter}.png"
        ico: Path = output / "ico" / f"{letter}.ico"
        download(url=FONT_AWESOME_URL + f"/solid/{letter}.svg", output=svg)
        args = [
            "magick",
            "convert",
            "-background",
            "none",
            svg,
            "-fill",
            color,
            "-colorize",
            "100",
        ]
        run(args=[*args, png])
        run(args=[*args, "-resize", "128x128", ico])



import click

from .delete.main import main as cmd_delete
from .set.main import main as cmd_set


@click.group(name="secret")
def main() -> None:
    pass


main.add_command(cmd=cmd_delete)
main.add_command(cmd=cmd_set)



from pathlib import Path

import click
from ishutils.common.run import run


@click.command(name="gpg")
@click.option(
    "-p",
    "--prefix",
    type=click.Path(exists=True, file_okay=False, dir_okay=True),
    default="gpg",
)
def main(prefix: str | Path) -> None:
    prefix = Path(prefix)
    run(args=["gpg", "--import", prefix / "secret.asc"])
    signing_key: str = str(
        run(args=["git", "config", "user.signingKey"], capture_output=True).stdout,
        encoding="utf-8",
    ).strip()
    run(args=["gpg", "--edit-key", signing_key, "trust"])



import click

from ..utils import gh_secret_delete


@click.command(name="pypi")
@click.option(
    "-R",
    "--repo",
    metavar="[HOST/]OWNER/REPO",
    help="Select another repository using the [HOST/]OWNER/REPO format",
)
def main(repo: str) -> None:
    gh_secret_delete(name="PYPI_USERNAME", repo=repo)
    gh_secret_delete(name="PYPI_PASSWORD", repo=repo)



import os
from pathlib import Path

import click
from ishutils.common.run import run


@click.command(name="ssh")
@click.option(
    "-p", "--prefix", type=click.Path(file_okay=False, dir_okay=True), default="gpg"
)
def main(prefix: str | Path) -> None:
    prefix = Path(prefix)
    os.makedirs(name=prefix, exist_ok=True)
    run(
        args=[
            "gpg",
            "--export-secret-keys",
            "--armor",
            "--output",
            prefix / "secret.asc",
        ]
    )



import subprocess

import click
from ishutils.common.run import run

from ..utils import gh_secret_set


@click.command(name="pypi")
@click.option(
    "-R",
    "--repo",
    metavar="[HOST/]OWNER/REPO",
    help="Select another repository using the [HOST/]OWNER/REPO format",
)
@click.option("-u", "--username", default="liblaf")
@click.option("-p", "--password")
def main(repo: str, username: str, password: str) -> None:
    if not password:
        password = str(
            run(args=["bw", "get", "password", "PyPI"], stdout=subprocess.PIPE).stdout,
            encoding="utf-8",
        )
    gh_secret_set(name="PYPI_USERNAME", body=username, repo=repo)
    gh_secret_set(name="PYPI_PASSWORD", body=password, repo=repo)



AVATAR_URL: dict[str, str] = {
    "Qiqi": "https://i0.hdslb.com/bfs/album/9450494338e94d665b43a05ebfb120fbcc9485ab.jpg",
}


FONT_AWESOME_URL: str = "https://github.com/FortAwesome/Font-Awesome/raw/6.x/svgs/"



import click

from .avatar import main as cmd_avatar
from .favicon import main as cmd_favicon


@click.group(name="assets", invoke_without_command=True)
@click.pass_context
def main(ctx: click.Context) -> None:
    if not ctx.invoked_subcommand:
        for name, cmd in main.commands.items():
            ctx.invoke(cmd)


main.add_command(cmd=cmd_avatar)
main.add_command(cmd=cmd_favicon)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ihelper',
 'ihelper.assets',
 'ihelper.git',
 'ihelper.git.secret',
 'ihelper.git.secret.delete',
 'ihelper.git.secret.set',
 'ihelper.key',
 'ihelper.key._import',
 'ihelper.key.export',
 'ihelper.update']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.1.3,<9.0.0',
 'ishutils>=0.1.2,<0.2.0',
 'python-slugify>=7.0.0,<8.0.0']

setup_kwargs = {
    'name': 'ihelper',
    'version': '0.1.0',
    'description': 'My Helpers',
    'long_description': '# ihelper\n\nMy Helpers\n',
    'author': 'Qin Li',
    'author_email': 'liblaf@outlook.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/liblaf/ihelper',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.11,<3.12',
}


setup(**setup_kwargs)



import click

from ._import.main import main as cmd_import
from .export.main import main as cmd_export


@click.group(name="key")
def main() -> None:
    pass


main.add_command(cmd=cmd_export)
main.add_command(cmd=cmd_import)



import click

from .apt import main as cmd_apt
from .brew import main as cmd_brew
from .ignore_io import main as cmd_ignore_io
from .snap import main as cmd_snap
from .tldr import main as cmd_tldr


@click.group(name="update", invoke_without_command=True)
@click.pass_context
def main(ctx: click.Context) -> None:
    if not ctx.invoked_subcommand:
        for name, cmd in main.commands.items():
            ctx.invoke(cmd)


main.add_command(cmd=cmd_apt)
main.add_command(cmd=cmd_brew)
main.add_command(cmd=cmd_ignore_io)
main.add_command(cmd=cmd_snap)
main.add_command(cmd=cmd_tldr)
